<?php
/**
 * Divine.
 *
 * @package      Divine
 * @link         http://restored316designs.com/themes
 * @author       Lauren Gaige // Restored 316 LLC
 * @copyright    Copyright (c) 2015, Restored 316 LLC, Released 3/11/2015
 * @license      GPL-2.0+
 */

// Starts the engine.
require_once get_template_directory() . '/lib/init.php';

// Adds HTML5 markup structure.
add_theme_support( 'html5' );

// Adds viewport meta tag for mobile browsers.
add_theme_support( 'genesis-responsive-viewport' );

// Sets up Theme.
require_once get_stylesheet_directory() . '/lib/theme-defaults.php';

// Adds Color Selection to WordPress Theme Customizer.
require_once get_stylesheet_directory() . '/lib/customize.php';

// Child theme (do not remove).
define( 'CHILD_THEME_NAME', 'Divine Theme' );
define( 'CHILD_THEME_URL', 'http://restored316designs.com' );
define( 'CHILD_THEME_VERSION', '1.1.0' );

add_action( 'after_setup_theme', 'divine_gutenberg_support' );
/**
 * Adds Gutenberg opt-in features and styling.
 *
 * @since 1.0.7
 */
function divine_gutenberg_support() {
	require_once get_stylesheet_directory() . '/lib/gutenberg/init.php';
}

// Installs Plugins.
require_once get_stylesheet_directory() . '/lib/plugins/tgm-plugin-activation/register-plugins.php';

add_action( 'wp_enqueue_scripts', 'divine_google_fonts' );
/**
 * Loads Responsive Menu, Google Fonts, and Icons.
 *
 * @since 1.0.0
 */
function divine_google_fonts() {
	wp_enqueue_script( 'divine-responsive-menu', get_stylesheet_directory_uri() . '/js/responsive-menu.js', array( 'jquery' ), '1.0.0' );
	wp_enqueue_style( 'google-font', '//fonts.googleapis.com/css?family=EB+Garamond|Open+Sans:400,300italic,300,400italic,600,600italic,700,700italic,800,800italic|Source+Serif+Pro', array() );
	wp_enqueue_style( 'dashicons' );
}

// Adds new image sizes.
add_image_size( 'blog-square-featured', 400, 400, true );
add_image_size( 'blog-vertical-featured', 400, 600, true );
add_image_size( 'sidebar-featured', 125, 125, true );
add_image_size( 'large-featured', 750, 500, true );

// Adds support for custom background.
add_theme_support( 'custom-background' );

// Adds Accessibility support.
add_theme_support( 'genesis-accessibility', array( 'headings' ) );

// Adds support for custom header.
add_theme_support(
	'custom-header', array(
		'width'           => 660,
		'height'          => 272,
		'flex-width'      => false,
		'flex-height'     => false,
		'header-selector' => '.site-title a',
		'header-text'     => false,
	)
);

// Adds support for 2-column footer widgets.
add_theme_support( 'genesis-footer-widgets', 2 );

// Unregisters layout settings.
genesis_unregister_layout( 'content-sidebar-sidebar' );
genesis_unregister_layout( 'sidebar-content-sidebar' );
genesis_unregister_layout( 'sidebar-sidebar-content' );

// Unregisters secondary sidebar.
unregister_sidebar( 'sidebar-alt' );

add_action( 'genesis_before', 'divine_widget_above_header' );
/**
 * Hooks widget area above header.
 *
 * @since 1.0.0
 */
function divine_widget_above_header() {

	genesis_widget_area(
		'widget-above-header', array(
			'before' => '<div class="widget-above-header widget-area"><div class="wrap">',
			'after'  => '</div></div>',
		)
	);

}

// Repositions the secondary navigation.
remove_action( 'genesis_after_header', 'genesis_do_subnav' );
add_action( 'genesis_before', 'genesis_do_subnav' );

// Adds widget to secondary navigation.
add_filter( 'genesis_nav_items', 'divine_social_icons', 10, 2 );
add_filter( 'wp_nav_menu_items', 'divine_social_icons', 10, 2 );
/**
 * Adds widget to primary navigation.
 *
 * @since 1.0.0
 *
 * @param  string   $menu HTML string representing the menu items.
 * @param  stdClass $args An object containing menu arguments.
 * @return string   $menu Updated $menu string.
 */
function divine_social_icons( $menu, $args ) {
	$args = (array) $args;
	if ( 'secondary' !== $args['theme_location'] ) {
		return $menu;
	}
	ob_start();
	genesis_widget_area( 'nav-social-menu' );
	$social = ob_get_clean();
	return $menu . $social;
}

// Positions post info above post title.
remove_action( 'genesis_entry_header', 'genesis_post_info', 12 );
add_action( 'genesis_entry_header', 'genesis_post_info', 9 );

add_filter( 'genesis_post_info', 'divine_post_info_filter' );
/**
 * Customizes the post info output.
 *
 * @since 1.0.0
 *
 * @param  string $post_info String to output in the post info.
 * @return string $post_info Updated string to output.
 */
function divine_post_info_filter( $post_info ) {

	$post_info = '[post_categories before="" sep=""]';
	return $post_info;

}

add_filter( 'genesis_post_meta', 'divine_post_meta_filter' );
/**
 * Customizes the post meta output.
 *
 * @since 1.0.0
 *
 * @param  string $post_meta String to output in the post meta.
 * @return string $post_meta Updated string to output.
 */
function divine_post_meta_filter( $post_meta ) {

	$post_meta = '<span class="dashicons dashicons-format-chat"></span><br>[post_comments]';
	return $post_meta;

}

// Adds post navigation (requires HTML5 support).
add_action( 'genesis_entry_footer', 'genesis_prev_next_post_nav', 15 );

// Adds support for after entry widget.
add_theme_support( 'genesis-after-entry-widget-area' );

add_action( 'genesis_before_content', 'divine_before_content' );
/**
 * Hooks before-content widget area to single posts.
 *
 * @since 1.0.0
 */
function divine_before_content() {

	if ( ! is_home() ) {
		return;
	}

	genesis_widget_area(
		'before-content', array(
			'before' => '<div class="before-content widget-area"><div class="wrap">',
			'after'  => '</div></div>',
		)
	);

}

add_action( 'genesis_after_sidebar_widget_area', 'divine_split_sidebars' );
/**
 * Adds split sidebars underneath the primary sidebar.
 *
 * @since 1.0.0
 */
function divine_split_sidebars() {

	foreach ( array( 'sidebar-split-left', 'sidebar-split-right', 'sidebar-split-bottom' ) as $area ) {
		echo '<div class="' . $area . '">';
		dynamic_sidebar( $area );
		echo '</div><!-- end #' . $area . '-->';
	}

}


add_filter( 'get_the_content_more_link', 'divine_read_more_link' );
/**
 * Customizes 'Read More' link.
 *
 * @since 1.0.0
 *
 * @return string       New string to output.
 */
function divine_read_more_link() {
	return '... <a class="more-link" href="' . get_permalink() . '">continue reading...</a>';
}

add_action( 'genesis_after', 'divine_widget_before_footer' );
/**
 * Hooks widget area before footer.
 *
 * @since 1.0.0
 */
function divine_widget_before_footer() {

	genesis_widget_area(
		'widget-before-footer', array(
			'before' => '<div class="widget-before-footer widget-area"><div class="wrap">',
			'after'  => '</div></div>',
		)
	);

}

// Repositions the footer widgets.
remove_action( 'genesis_before_footer', 'genesis_footer_widget_areas' );
add_action( 'genesis_after', 'genesis_footer_widget_areas' );

// Repositions the footer.
remove_action( 'genesis_footer', 'genesis_footer_markup_open', 5 );
remove_action( 'genesis_footer', 'genesis_do_footer' );
remove_action( 'genesis_footer', 'genesis_footer_markup_close', 15 );
add_action( 'genesis_after', 'genesis_footer_markup_open', 11 );
add_action( 'genesis_after', 'genesis_do_footer', 12 );
add_action( 'genesis_after', 'genesis_footer_markup_close', 13 );

add_filter( 'genesis_comment_list_args', 'divine_comments_gravatar' );
/**
 * Modifies the size of the Gravatar in the entry comments.
 *
 * @since 1.0.0
 *
 * @param  array $args Array of available arguments.
 * @return array $args Updated arguments array.
 */
function divine_comments_gravatar( $args ) {

	$args['avatar_size'] = 96;
	return $args;

}

add_filter( 'genesis_author_box_gravatar_size', 'divine_author_box_gravatar' );
/**
 * Modifies the size of the Gravatar in the author box.
 *
 * @since 1.0.0
 *
 * @param int $size Current size of gravatar. Default is 70.
 * @return int Modified size of gravatar.
 */
function divine_author_box_gravatar( $size ) {

	return 125;

}

add_filter( 'genesis_footer_creds_text', 'divine_custom_footer_creds_text' );
/**
 * Customizes the footer credits.
 *
 * @since 1.0.0
 */
function divine_custom_footer_creds_text() {
	echo '<div class="creds"><p>';
	echo 'Copyright &copy; ';
	echo date( 'Y' );
	echo ' &middot; <a target="_blank" href="http://restored316designs.com/themes">Divine theme</a> by <a target="_blank" href="http://www.restored316designs.com">Restored 316</a>';
	echo '</p></div>';

}

// Adds Theme Support for WooCommerce.
add_theme_support( 'genesis-connect-woocommerce' );

// Removes Related Products.
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );

add_action( 'woocommerce_after_shop_loop_item', 'remove_add_to_cart_buttons', 1 );
/**
 * Removes Add to Cart on Archives.
 *
 * @since 1.0.0
 */
function remove_add_to_cart_buttons() {

	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart' );

}

add_filter( 'loop_shop_columns', 'loop_columns' );
/**
 * Changes number or products per row to 3.
 *
 * @since 1.0.0
 *
 * @return int Number of WooCommerce shop columns.
 */
if ( ! function_exists( 'loop_columns' ) ) {
	function loop_columns() {
		return 3; // 3 products per row
	}
}

add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 12;' ), 20 );

add_action( 'after_setup_theme', 'divine_woo_gallery' );
/**
 * Adds WooCommerce gallery options.
 *
 * @since 1.0.0
 */
function divine_woo_gallery() {
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}


// Registers widget areas.
genesis_register_sidebar(
	array(
		'id'          => 'sidebar-split-left',
		'name'        => __( 'Sidebar Split Left', 'divine-theme' ),
		'description' => __( 'This is the left side of the split sidebar', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'sidebar-split-right',
		'name'        => __( 'Sidebar Split Right', 'divine-theme' ),
		'description' => __( 'This is the right side of the split sidebar', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'sidebar-split-bottom',
		'name'        => __( 'Sidebar Split Bottom', 'divine-theme' ),
		'description' => __( 'This is the bottom of the split sidebar', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'before-content',
		'name'        => __( 'Home - Before Content', 'divine-theme' ),
		'description' => __( 'This is the slider section on the home page.', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'home-slider',
		'name'        => __( 'Home - Slider', 'divine-theme' ),
		'description' => __( 'This is the slider section on the home page.', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'home-top',
		'name'        => __( 'Home - Top', 'divine-theme' ),
		'description' => __( 'This is the top section of the home page.', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'home-triple-bottom',
		'name'        => __( 'Home - Triple Bottom', 'divine-theme' ),
		'description' => __( 'This is the bottom section of the home page.', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'home-double-bottom',
		'name'        => __( 'Home - Double Bottom', 'divine-theme' ),
		'description' => __( 'This is the bottom section of the home page.', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'category-index',
		'name'        => __( 'Category Index', 'divine-theme' ),
		'description' => __( 'This is the category index for the category index page template.', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'widget-above-header',
		'name'        => __( 'Widget Above Header', 'divine-theme' ),
		'description' => __( 'This is the widget area above the header', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'widget-before-footer',
		'name'        => __( 'Widget Before Footer', 'divine-theme' ),
		'description' => __( 'This is the widget area above the header', 'divine-theme' ),
	)
);
genesis_register_sidebar(
	array(
		'id'          => 'nav-social-menu',
		'name'        => __( 'Nav Social Menu', 'divine-theme' ),
		'description' => __( 'This is the nav social menu section.', 'divine-theme' ),
	)
);
