<?php
/**
 * Gutenberg theme support.
 *
 * @package Divine
 * @author  Lauren Gaige // Restored 316 LLC
 * @license GPL-2.0-or-later
 * @link    https://www.restored316designs.com/themes
 */

add_action( 'wp_enqueue_scripts', 'divine_enqueue_gutenberg_frontend_styles' );
/**
 * Enqueues Gutenberg front-end styles.
 *
 * @since 1.0.7
 */
function divine_enqueue_gutenberg_frontend_styles() {

	$child_theme_slug = defined( 'CHILD_THEME_NAME' ) && CHILD_THEME_NAME ? sanitize_title_with_dashes( CHILD_THEME_NAME ) : 'divine-theme';

	wp_enqueue_style(
		'divine-gutenberg',
		get_stylesheet_directory_uri() . '/lib/gutenberg/front-end.css',
		array( $child_theme_slug ),
		CHILD_THEME_VERSION
	);

}

add_action( 'enqueue_block_editor_assets', 'divine_block_editor_styles' );
/**
 * Enqueues Gutenberg admin editor fonts and styles.
 *
 * @since 1.0.7
 */
function divine_block_editor_styles() {

	wp_enqueue_style(
		'divine-gutenberg-fonts',
		'https://fonts.googleapis.com/css?family=EB+Garamond|Open+Sans:400,300italic,300,400italic,600,600italic,700,700italic,800,800italic|Source+Serif+Pro',
		array(),
		CHILD_THEME_VERSION
	);

}

// Adds support for editor styles.
add_theme_support( 'editor-styles' );

// Enqueueseditor styles.
add_editor_style( '/lib/gutenberg/style-editor.css' );

// Adds support for block alignments.
add_theme_support( 'align-wide' );

// Makes media embeds responsive.
add_theme_support( 'responsive-embeds' );

// Adds support for editor font sizes.
add_theme_support(
	'editor-font-sizes',
	array(
		array(
			'name'      => __( 'Small', 'divine-theme' ),
			'shortName' => __( 'S', 'divine-theme' ),
			'size'      => 12,
			'slug'      => 'small',
		),
		array(
			'name'      => __( 'Normal', 'divine-theme' ),
			'shortName' => __( 'M', 'divine-theme' ),
			'size'      => 16,
			'slug'      => 'normal',
		),
		array(
			'name'      => __( 'Large', 'divine-theme' ),
			'shortName' => __( 'L', 'divine-theme' ),
			'size'      => 20,
			'slug'      => 'large',
		),
		array(
			'name'      => __( 'Larger', 'divine-theme' ),
			'shortName' => __( 'XL', 'divine-theme' ),
			'size'      => 24,
			'slug'      => 'larger',
		),
	)
);

add_action( 'after_setup_theme', 'divine_content_width', 0 );
/**
 * Sets content width to match the “wide” Gutenberg block width.
 *
 * @since 1.0.7
 */
function divine_content_width() {

	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound -- See https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/924
	$GLOBALS['content_width'] = apply_filters( 'divine_content_width', 1160 );

}
